| Title: | Builds standardized, modular shiny dashboard with a UNHCR style |
|---|---|
| Description: | Wrapper for {golem} that automates dashboard file generation. |
| Authors: | Alan carlson [aut, cre], Edouard Legoupil [aut, ctb] |
| Maintainer: | Edouard Legoupil <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.75.2 |
| Built: | 2026-06-07 09:46:03 UTC |
| Source: | https://github.com/Edouard-Legoupil/graveler |
An illustration of graveler applied to a humanitarian protection monitoring dashboard
example_protection()example_protection()
if (interactive()) { example_protection() }if (interactive()) { example_protection() }
An illustration of graveler applied to a humanitarian response tracking dashboard
example_response()example_response()
if (interactive()) { example_response() }if (interactive()) { example_response() }
Creates golem directory and header from template info
graveler_dashboard(path, ...)graveler_dashboard(path, ...)
path |
path to file |
... |
other parameters |
Creates module of the specified name
level_up(name, pkg = get_graveler_wd(), open = TRUE, dir_create = TRUE)level_up(name, pkg = get_graveler_wd(), open = TRUE, dir_create = TRUE)
name |
name |
pkg |
package name |
open |
boolean |
dir_create |
boolean |